/*******************************************************************

This code include the construction of the variables and indicators used
in Elias, Lacetera and Macis (AER P&P, 2015), as well as the estimations
described in the paper for the analysis of support fo legalized prostitution
and slavery contracts.

Further analyses and details can be found in Elias et al. (NBER Working Paper, 2015).

*******************************************************************/


clear
set more off

//THE DATASET TO USE FOR WHAT FOLLOWS IS aerpp-dataset2.dta 


//SOME BASIC DESCRIPTIVES AND RANDOMIZATION CHECKS
sum

table sgroups, c(mean y mean age mean male mean children mean altruist)


foreach v in wave y race relationship education employment income religion ideology {
tab `v' sgroups, col
}


//DUMMIES TO SELECT SUBSETS OF THE OVERALL CONDITIONS (ACCORDING TO ANALYSIS TO RUN) [full set of treatment ocndition include some not used here]
gen prostitution	= (sgroups==1|sgroups==3|sgroups==7|sgroups==9)
gen slavery			= (sgroups==1|sgroups==4|sgroups==10|sgroups==11)


//generate variables for analysis

//note: group numbers for relevant treatment conditions are not in consecutive order

foreach i in 1 3 4 7 9 10 11   {
gen sgroupsd`i'=(sgroups==`i')
}


gen age2=age^2
gen college=(education>=5)
tab ideology, gen (ideol_d)
//IN MOST ANALYSES, THE RESIDUAL CATEGORY 4 IS EXCLUDED BECAUSE IT IS SMALL AND TOO HETEROGENEOUS

tab income, gen (income_d)
tab religion, gen (relig_d)
tab education, gen (educ_d)
tab race, gen (ethn_d)
tab relationship, gen (rel_d)
tab children, gen (kid_d)
tab employment, gen (empl_d)

gen atheist=.
replace atheist=1 if religion==1
replace atheist=0 if religion>1&religion<=5

gen highearn=.
replace highearn=1 if income==4|income==5
replace highearn=0 if income==1|income==2|income==3




//INTERACTIONS OF TREATMENTS AND VARIABLES USED IN HETEROGENOUS EFFECTS ANALYSES

foreach i in 1 3 4 7 9 10 11   {
gen male_`i' = male*sgroupsd`i'
}

foreach i in 1 3 4 7 9 10 11   {
gen college_`i' = college*sgroupsd`i'
}

foreach i in 1 3 4 7 9 10 11   {
gen atheist_`i' = atheist*sgroupsd`i'
}

foreach i in 1 3 4 7 9 10 11   {
gen highearn_`i' = highearn*sgroupsd`i'
}

forvalues j=2(1)4  {
	foreach i in 1 3 4 7 9 10 11   {
gen ideol_`i'_`j' = ideol_d`j'*sgroupsd`i'
   }
}



//GENERATE A GLOBAL "CONTROL VARIABLE" FOR THE REGRESSIONS WITH CONTROLS BELOW
global controls male age age2 ethn_d2-ethn_d5 educ_d2-educ_d6 rel_d2-rel_d5 children empl_d2-empl_d7/*
*/ income_d2-income_d5 relig_d2-relig_d5 ideol_d2-ideol_d4 altruist i.state i.wave

sum male age age2 ethn_d2-ethn_d5 educ_d2-educ_d6 rel_d2-rel_d5 children empl_d2-empl_d7 income_d2-income_d5 relig_d2-relig_d5 ideol_d2-ideol_d4 altruist if prostitution==1
sum male age age2 ethn_d2-ethn_d5 educ_d2-educ_d6 rel_d2-rel_d5 children empl_d2-empl_d7 income_d2-income_d5 relig_d2-relig_d5 ideol_d2-ideol_d4 altruist if slavery==1


//generate a global variable for the sequence of treatment group dummies
global conditions sgroupsd3 sgroupsd4 sgroupsd7 sgroupsd9 sgroupsd10 sgroupsd11



//ANALYSES

//mean relabilility per group
table sgroups, c(mean reliable n reliable)


//regression for  reliability answer (limited to conditions with a text)
reg  reliable  sgroupsd9 sgroupsd10 sgroupsd11



//SUPPORT RATES PER GROUP

mean y, over (sgroups)

//regression analyses


*prostitution

reg y $conditions if prostitution==1, rob

//est. share for legalizing prostitution with no txt is coefficient on sgroupd3

//est. share for legalizing prostitution (prostitution text)
lincom (sgroupsd9-sgroupsd7)

// est. diff in favor of legalizing prostitution between prostitution text and no text
lincom (sgroupsd9-sgroupsd7)-(sgroupsd3)


*slavery

reg y $conditions if slavery==1, rob

//est. share for legalizing slavery with no txt is coefficient on sgroupd4:

//est. share for legalizing slavery (slavery text)
lincom (sgroupsd11-sgroupsd10)

// est. diff in favor of legalizing slavery between slavery text and no text
lincom (sgroupsd11-sgroupsd10)-(sgroupsd4)



//WITH CONTROL VARIABLES

*prostitution

reg y $conditions $controls if prostitution==1, rob

//est. share for legalizing prostitution with no txt is coefficient on sgroupd3

//est. share for legalizing prostitution (prostitution text)
lincom (sgroupsd9-sgroupsd7)

// est. diff in favor of legalizing prostitution between prostitution text and no text
lincom (sgroupsd9-sgroupsd7)-(sgroupsd3)



*slavery

reg y $conditions $controls if slavery==1, rob

//est. share for legalizing slavery with no txt is coefficient on sgroupd4:

//est. share for legalizing slavery (slavery text)
lincom (sgroupsd11-sgroupsd10)

// est. diff in favor of legalizing slavery between slavery text and no text
lincom (sgroupsd11-sgroupsd10)-(sgroupsd4)



// GENDER

mean y, over (male sgroups)


*prostitution

reg y $conditions male_1-male_11 if prostitution==1


//WOMEN

//est. share for legalizing prostitution with no txt is coefficient on sgroupd3

//est. share for legalizing prostitution (prostitution text)
lincom (sgroupsd9-sgroupsd7)

// est. diff in favor of legalizing prostitution between prostitution text and no text
lincom (sgroupsd9-sgroupsd7)-(sgroupsd3)



//MEN

//est. share for org.mkt with no txt
lincom (sgroupsd3+male_3)-male_1

//est. share for org.mkt (pros text)
lincom (sgroupsd9+male_9-sgroupsd7-male_7)

// est. diff in favor of legalizing prostitution between prostitution text and no text
lincom (sgroupsd9+male_9-sgroupsd7-male_7)-((sgroupsd3+male_3)-male_1)


//MEN VS WOMEN
//est. share for legalizing prostitution with no txt:
lincom (male_3)-male_1

//est. share for legalizing prostitution (pros text)
lincom (male_9-male_7)

//diff between the two
lincom male_9-male_7-(male_3)+male_1



*slavery

reg y $conditions male_1-male_11 if slavery==1

//WOMEN

//est. share for legalizing slavery with no txt is coefficient on sgroupd4

//est. share for legalizing slavery (slavery text)
lincom (sgroupsd11-sgroupsd10)

// est. diff in favor of legalizing slavery between slavery text and no text
lincom (sgroupsd11-sgroupsd10)-(sgroupsd4)


//MEN

//est. share for slavery with no txt
lincom (sgroupsd4+male_4)-male_1

//est. share for slavery (slavery text)
lincom (sgroupsd11+male_11-sgroupsd10-male_10)

// est. diff in favor of legalizing slavery between slavery text and no text
lincom (sgroupsd11+male_11-sgroupsd10-male_10)-((sgroupsd4+male_4)-male_1)


//MEN VS WOMEN
//est. share for slavery with no txt:
lincom (male_4)-male_1

//est. share for slavery (slavery text)
lincom (male_11-male_10)

//diff between the two
lincom (male_11-male_10)- (male_4-male_1)



//WITH CONTROL VARIABLES


*prostitution

reg y $conditions male_1-male_11 $controls if prostitution==1

//WOMEN

//est. share for legalizing prostitution with no txt is coefficient on sgroupd3

//est. share for legalizing prostitution (prostitution text)
lincom (sgroupsd9-sgroupsd7)

// est. diff in favor of legalizing prostitution between prostitution text and no text
lincom (sgroupsd9-sgroupsd7)-(sgroupsd3)


//MEN

//est. share for org.mkt with no txt
lincom (sgroupsd3+male_3)-male_1

//est. share for org.mkt (pros text)
lincom (sgroupsd9+male_9-sgroupsd7-male_7)

// est. diff in favor of legalizing prostitution between prostitution text and no text
lincom (sgroupsd9+male_9-sgroupsd7-male_7)-((sgroupsd3+male_3)-male_1)


//MEN VS WOMEN
//est. share for legalizing prostitution with no txt:
lincom (male_3-male_1)

//est. share for legalizing prostitution (pros text)
lincom (male_9-male_7)

//diff between the two
lincom (male_9-male_7)- (male_3-male_1) 



*slavery

reg y $conditions male_1-male_11 $controls if slavery==1

//WOMEN

//est. share for legalizing slavery with no txt is coefficient on sgroupd4

//est. share for legalizing slavery (slavery text)
lincom (sgroupsd11-sgroupsd10)

// est. diff in favor of legalizing slavery between slavery text and no text
lincom (sgroupsd11-sgroupsd10)-(sgroupsd4)


//MEN

//est. share for slavery with no txt
lincom (sgroupsd4+male_4)-male_1

//est. share for slavery (slavery text)
lincom (sgroupsd11+male_11-sgroupsd10-male_10)

// est. diff in favor of legalizing slavery between slavery text and no text
lincom (sgroupsd11+male_11-sgroupsd10-male_10)-((sgroupsd4+male_4)-male_1)


//MEN VS WOMEN
//est. share for slavery with no txt:
lincom (male_4)-male_1

//est. share for slavery (slavery text)
lincom (male_11-male_10)


//diff between the two
lincom (male_11-male_10)- (male_4-male_1)




//EDUCATION (<COLLEGE VS. COLLEGE+)

mean y, over (college sgroups)




*prostitution

reg y $conditions college_1-college_11 if prostitution==1

//<COLLEGE

//est. share for legalizing prostitution with no txt is coefficient on sgroupd3

//est. share for legalizing prostitution (prostitution text)
lincom (sgroupsd9-sgroupsd7)

// est. diff in favor of legalizing prostitution between prostitution text and no text
lincom (sgroupsd9-sgroupsd7)-(sgroupsd3)



//COLLEGE+

//est. share for org.mkt with no txt
lincom (sgroupsd3+college_3)-college_1

//est. share for org.mkt (pros text)
lincom (sgroupsd9+college_9-sgroupsd7-college_7)

// est. diff in favor of legalizing prostitution between prostitution text and no text
lincom (sgroupsd9+college_9-sgroupsd7-college_7)-((sgroupsd3+college_3)-college_1)


//COLLEGE+ VS <COLLEGE
//est. share for legalizing prostitution with no txt:
lincom (college_3)-college_1

//est. share for legalizing prostitution (pros text)
lincom (college_9-college_7)

//diff between the two
lincom  (college_9-college_7) - (college_3-college_1)



*slavery

reg y $conditions college_1-college_11 if slavery==1

//<COLLEGE

//est. share for legalizing slavery with no txt is coefficient on sgroupd4:

//est. share for legalizing slavery (slavery text)
lincom (sgroupsd11-sgroupsd10)

// est. diff in favor of legalizing slavery between slavery text and no text
lincom (sgroupsd11-sgroupsd10)-(sgroupsd4)


//COLLEGE+

//est. share for slavery with no txt
lincom (sgroupsd4+college_4)-college_1

//est. share for slavery (slavery text)
lincom (sgroupsd11+college_11-sgroupsd10-college_10)

// est. diff in favor of legalizing slavery between slavery text and no text
lincom (sgroupsd11+college_11-sgroupsd10-college_10)-((sgroupsd4+college_4)-college_1)


//COLLEGE+ VS <COLLEGE
//est. share for slavery with no txt:
lincom (college_4)-college_1

//est. share for slavery (slavery text)
lincom (college_11-college_10)

//diff between the two
lincom  (college_11-college_10) - ((college_4)-college_1)




//WITH CONTROL VARIABLES


*prostitution


reg y $conditions college_1-college_11 $controls if prostitution==1

//<COLLEGE

//est. share for legalizing prostitution with no txt is coefficient on sgroupd3:

//est. share for legalizing prostitution (prostitution text)
lincom (sgroupsd9-sgroupsd7)

// est. diff in favor of legalizing prostitution between prostitution text and no text
lincom (sgroupsd9-sgroupsd7)-(sgroupsd3)


//COLLEGE+

//est. share for org.mkt with no txt
lincom (sgroupsd3+college_3)-college_1

//est. share for org.mkt (pros text)
lincom (sgroupsd9+college_9-sgroupsd7-college_7)

// est. diff in favor of legalizing prostitution between prostitution text and no text
lincom (sgroupsd9+college_9-sgroupsd7-college_7)-((sgroupsd3+college_3)-college_1)


//COLLEGE+ VS <COLLEGE
//est. share for legalizing prostitution with no txt:
lincom (college_3)-college_1

//est. share for legalizing prostitution (pros text)
lincom (college_9-college_7)

//diff between the two
lincom  (college_9-college_7) - ((college_3)-college_1)



*slavery

reg y $conditions college_1-college_11 $controls if slavery==1

//<COLLEGE

//est. share for legalizing slavery with no txt is coefficient on sgroupd4:

//est. share for legalizing slavery (slavery text)
lincom (sgroupsd11-sgroupsd10)

// est. diff in favor of legalizing slavery between slavery text and no text
lincom (sgroupsd11-sgroupsd10)-(sgroupsd4)


//COLLEGE+

//est. share for slavery with no txt
lincom (sgroupsd4+college_4)-college_1

//est. share for slavery (slavery text)
lincom (sgroupsd11+college_11-sgroupsd10-college_10)

// est. diff in favor of legalizing slavery between slavery text and no text
lincom (sgroupsd11+college_11-sgroupsd10-college_10)-((sgroupsd4+college_4)-college_1)


//COLLEGE+ VS <COLLEGE
//est. share for slavery with no txt:
lincom (college_4)-college_1

//est. share for slavery (slavery text)
lincom (college_11-college_10)

//diff between the two
lincom  ((college_11-college_10)) - ((college_4)-college_1)




//RELIGIOSITY

mean y, over (atheist sgroups)


*prostitution
reg y $conditions atheist_1-atheist_11 if prostitution==1

//RELIGIOUS

//est. share for legalizing prostitution with no txt is coefficient on sgroupd3

//est. share for legalizing prostitution (prostitution text)
lincom (sgroupsd9-sgroupsd7)

// est. diff in favor of legalizing prostitution between prostitution text and no text
lincom (sgroupsd9-sgroupsd7)-(sgroupsd3)


//NON-RELIGIOUS

//est. share for org.mkt with no txt
lincom (sgroupsd3+atheist_3)-atheist_1

//est. share for org.mkt (pros text)
lincom (sgroupsd9+atheist_9-sgroupsd7-atheist_7)

// est. diff in favor of legalizing prostitution between prostitution text and no text
lincom (sgroupsd9+atheist_9-sgroupsd7-atheist_7)-((sgroupsd3+atheist_3)-atheist_1)


//NON-RELIGIOUS VS RELIGIOUS
//est. share for legalizing prostitution with no txt:
lincom (atheist_3)-atheist_1

//est. share for legalizing prostitution (pros text)
lincom (atheist_9-atheist_7)

//diff between the two
lincom  (atheist_9-atheist_7) - ((atheist_3)-atheist_1)



*slavery

reg y $conditions atheist_1-atheist_11 if slavery==1

//RELIGIOUS

//est. share for legalizing slavery with no txt is coefficient on sgroupd4:

//est. share for legalizing slavery (slavery text)
lincom (sgroupsd11-sgroupsd10)

// est. diff in favor of legalizing slavery between slavery text and no text
lincom (sgroupsd11-sgroupsd10)-(sgroupsd4)


//NON-RELIGIOUS

//est. share for slavery with no txt
lincom (sgroupsd4+atheist_4)-atheist_1

//est. share for slavery (slavery text)
lincom (sgroupsd11+atheist_11-sgroupsd10-atheist_10)

// est. diff in favor of legalizing slavery between slavery text and no text
lincom (sgroupsd11+atheist_11-sgroupsd10-atheist_10)-((sgroupsd4+atheist_4)-atheist_1)


//NON-RELIGIOUS VS RELIGIOUS
//est. share for slavery with no txt:
lincom (atheist_4)-atheist_1

//est. share for slavery (slavery text)
lincom (atheist_11-atheist_10)

//diff between the two
lincom  (atheist_11-atheist_10) - ((atheist_4)-atheist_1)



//WITH CONTROL VARIABLES

*prostitution

reg y $conditions atheist_1-atheist_11 $controls if prostitution==1

//RELIGIOUS

//est. share for legalizing prostitution with no txt is coefficient on sgroupd3

//est. share for legalizing prostitution (prostitution text)
lincom (sgroupsd9-sgroupsd7)

// est. diff in favor of legalizing prostitution between prostitution text and no text
lincom (sgroupsd9-sgroupsd7)-(sgroupsd3)


//NON-RELIGIOUS:  "D-in-D" analysis by testing differences in coefficient estimates

//est. share for org.mkt with no txt
lincom (sgroupsd3+atheist_3)-atheist_1

//est. share for org.mkt (pros text)
lincom (sgroupsd9+atheist_9-sgroupsd7-atheist_7)

// est. diff in favor of legalizing prostitution between prostitution text and no text
lincom (sgroupsd9+atheist_9-sgroupsd7-atheist_7)-((sgroupsd3+atheist_3)-atheist_1)


//NON-RELIGIOUS VS RELIGIOUS
//est. share for legalizing prostitution with no txt:
lincom (atheist_3)-atheist_1

//est. share for legalizing prostitution (pros text)
lincom (atheist_9-atheist_7)

//diff between the two
lincom  (atheist_9-atheist_7) - ((atheist_3)-atheist_1)


*slavery

reg y $conditions atheist_1-atheist_11 $controls if slavery==1

//RELIGIOUS

//est. share for legalizing slavery with no txt is coefficient on sgroupd4

//est. share for legalizing slavery (slavery text)
lincom (sgroupsd11-sgroupsd10)

// est. diff in favor of legalizing slavery between slavery text and no text
lincom (sgroupsd11-sgroupsd10)-(sgroupsd4)


//NON-RELIGIOUS

//est. share for slavery with no txt
lincom (sgroupsd4+atheist_4)-atheist_1

//est. share for slavery (slavery text)
lincom (sgroupsd11+atheist_11-sgroupsd10-atheist_10)

// est. diff in favor of legalizing slavery between slavery text and no text
lincom (sgroupsd11+atheist_11-sgroupsd10-atheist_10)-((sgroupsd4+atheist_4)-atheist_1)


//NON-RELIGIOUS VS RELIGIOUS
//est. share for slavery with no txt:
lincom (atheist_4)-atheist_1

//est. share for slavery (slavery text)
lincom (atheist_11-atheist_10)

//diff between the two
lincom  (atheist_11-atheist_10) - ((atheist_4)-atheist_1)





//POLITICAL VIEWS

mean y, over (ideology sgroups)


*protitution


reg y $conditions ideol_1_2- ideol_11_3 if prostitution==1 & ideology>=1&ideology<=3

//CONSERVATIVES

//est. share for prostitution with no txt is coefficient on sgroupsd3

//est. share for org.mkt (prost text)
lincom (sgroupsd9-sgroupsd7)

// est. diff in favor of prostitution between org text and no text
lincom (sgroupsd9-sgroupsd7)-(sgroupsd3)


//LIBERALS

//est. share for prostitution with no txt
lincom (sgroupsd3+ideol_3_2)-ideol_1_2

//est. share for prostitution (prost text)
lincom (sgroupsd9+ideol_9_2-sgroupsd7-ideol_7_2)

// est. diff in favor of prostitution between prost text and no text
lincom (sgroupsd9+ideol_9_2-sgroupsd7-ideol_7_2)-((sgroupsd3+ideol_3_2)-ideol_1_2)



//MODERATES

//est. share for org.mkt with no txt
lincom (sgroupsd3+ideol_3_3)-ideol_1_3

//est. share for prostitution (prost text)
lincom (sgroupsd9+ideol_9_3-sgroupsd7-ideol_7_3)

// est. diff in favor of prostitution between prost. text and no text
lincom (sgroupsd9+ideol_9_3-sgroupsd7-ideol_7_3)-(sgroupsd3+ideol_3_3-ideol_1_3)



//LIBERALS - CONSERVATIVES
//est. share for prostitution with no txt:
lincom ideol_3_2-ideol_1_2

//est. share for prostitution (prost. text)
lincom ideol_9_2-ideol_7_2

//diff between the two
lincom (ideol_9_2-ideol_7_2)-(ideol_3_2-ideol_1_2)


//LIBERALS - MODERATES
//est. share for prostitution with no txt:
lincom (ideol_3_2-ideol_1_2)-(ideol_3_3-ideol_1_3)

//est. share for prostitution (prost. text)
lincom (ideol_9_2-ideol_7_2)-(ideol_9_3-ideol_7_3)

//diff between the two
lincom ((ideol_3_2-ideol_1_2)-(ideol_3_3-ideol_1_3))-((ideol_9_2-ideol_7_2)-(ideol_9_3-ideol_7_3))


//MODERATES - CONSERVATIVES
//est. share for prostitutuion with no txt:
lincom ideol_3_3-ideol_1_3

//est. share for prostitution (prost. text)
lincom ideol_9_3-ideol_7_3

//diff between the two
lincom (ideol_3_3-ideol_1_3)-(ideol_9_3-ideol_7_3)


*slavery

reg y $conditions ideol_1_2- ideol_11_3 if slavery==1 & ideology>=1&ideology<=3

//CONSERVATIVES

//est. share for org.mkt with no txt is coefficient on sgroupsd4:

//est. share for prostitution (prost. text)
lincom (sgroupsd11-sgroupsd10)

// est. diff in favor of prostitution between prost. text and no text
lincom (sgroupsd11-sgroupsd10)-(sgroupsd4)


//LIBERALS

//est. share for prostitution with no txt
lincom (sgroupsd4+ideol_4_2)-ideol_1_2

//est. share for prostitution (prost. text)
lincom (sgroupsd11+ideol_11_2-sgroupsd10-ideol_10_2)

// est. diff in favor of prostitution between prost. text and no text
lincom (sgroupsd11+ideol_11_2-sgroupsd10-ideol_10_2)-((sgroupsd4+ideol_4_2)-ideol_1_2)


//MODERATES

//est. share for prostitution with no txt
lincom (sgroupsd4+ideol_4_3)-ideol_1_3

//est. share for prostitution (prost. text)
lincom (sgroupsd11+ideol_11_3-sgroupsd10-ideol_10_3)

// est. diff in favor of prostitution between prost. text and no text
lincom (sgroupsd11+ideol_11_3-sgroupsd10-ideol_10_3)-(sgroupsd4+ideol_4_3-ideol_1_3)


//LIBERALS - CONSERVATIVES
//est. share for prostitution with no txt:
lincom ideol_4_2-ideol_1_2

//est. share for prostitution (prost. text)
lincom ideol_11_2-ideol_10_2

//diff between the two
lincom (ideol_11_2-ideol_10_2)-(ideol_4_2-ideol_1_2)


//LIBERALS - MODERATES
//est. share for prostitution with no txt:
lincom (ideol_4_2-ideol_1_2)-(ideol_4_3-ideol_1_3)

//est. share for prostitution (prost. text)
lincom (ideol_11_2-ideol_10_2)-(ideol_11_3-ideol_10_3)

//diff between the two
lincom ((ideol_11_2-ideol_10_2)-(ideol_11_3-ideol_10_3)) - ((ideol_4_2-ideol_1_2)-(ideol_4_3-ideol_1_3))


//MODERATES - CONSERVATIVES
//est. share for prostitution with no txt:
lincom ideol_4_3-ideol_1_3

//est. share for prostitution (prost. text)
lincom ideol_11_3-ideol_10_3

//diff between the two
lincom (ideol_11_3-ideol_10_3) - (ideol_4_3-ideol_1_3)



//WITH CONTROL VARIABLES

*prostitution
reg y $conditions ideol_1_2- ideol_11_3 $controls if prostitution==1 & ideology>=1&ideology<=3

//CONSERVATIVES

//est. share for prostitution with no txt is coefficient on sgroupsd3

//est. share for org.mkt (prost text)
lincom (sgroupsd9-sgroupsd7)

// est. diff in favor of prostitution between org text and no text
lincom (sgroupsd9-sgroupsd7)-(sgroupsd3)


//LIBERALS

//est. share for prostitution with no txt
lincom (sgroupsd3+ideol_3_2)-ideol_1_2

//est. share for prostitution (prost text)
lincom (sgroupsd9+ideol_9_2-sgroupsd7-ideol_7_2)

// est. diff in favor of prostitution between prost text and no text
lincom (sgroupsd9+ideol_9_2-sgroupsd7-ideol_7_2)-((sgroupsd3+ideol_3_2)-ideol_1_2)



//MODERATES

//est. share for org.mkt with no txt
lincom (sgroupsd3+ideol_3_3)-ideol_1_3

//est. share for prostitution (prost text)
lincom (sgroupsd9+ideol_9_3-sgroupsd7-ideol_7_3)

// est. diff in favor of prostitution between prost. text and no text
lincom (sgroupsd9+ideol_9_3-sgroupsd7-ideol_7_3)-(sgroupsd3+ideol_3_3-ideol_1_3)



//LIBERALS - CONSERVATIVES
//est. share for prostitution with no txt:
lincom ideol_3_2-ideol_1_2

//est. share for prostitution (prost. text)
lincom ideol_9_2-ideol_7_2

//diff between the two
lincom (ideol_9_2-ideol_7_2)-(ideol_3_2-ideol_1_2)


//LIBERALS - MODERATES
//est. share for prostitution with no txt:
lincom (ideol_3_2-ideol_1_2)-(ideol_3_3-ideol_1_3)

//est. share for prostitution (prost. text)
lincom (ideol_9_2-ideol_7_2)-(ideol_9_3-ideol_7_3)

//diff between the two
lincom ((ideol_3_2-ideol_1_2)-(ideol_3_3-ideol_1_3))-((ideol_9_2-ideol_7_2)-(ideol_9_3-ideol_7_3))


//MODERATES - CONSERVATIVES
//est. share for prostitutuion with no txt:
lincom ideol_3_3-ideol_1_3

//est. share for prostitution (prost. text)
lincom ideol_9_3-ideol_7_3

//diff between the two
lincom (ideol_3_3-ideol_1_3)-(ideol_9_3-ideol_7_3)


*slavery
reg y $conditions ideol_1_2- ideol_11_3 $controls if slavery==1 & ideology>=1&ideology<=3

//CONSERVATIVES

//est. share for org.mkt with no txt is coefficient on sgroupsd4:

//est. share for prostitution (prost. text)
lincom (sgroupsd11-sgroupsd10)

// est. diff in favor of prostitution between prost. text and no text
lincom (sgroupsd11-sgroupsd10)-(sgroupsd4)


//LIBERALS

//est. share for prostitution with no txt
lincom (sgroupsd4+ideol_4_2)-ideol_1_2

//est. share for prostitution (prost. text)
lincom (sgroupsd11+ideol_11_2-sgroupsd10-ideol_10_2)

// est. diff in favor of prostitution between prost. text and no text
lincom (sgroupsd11+ideol_11_2-sgroupsd10-ideol_10_2)-((sgroupsd4+ideol_4_2)-ideol_1_2)


//MODERATES

//est. share for prostitution with no txt
lincom (sgroupsd4+ideol_4_3)-ideol_1_3

//est. share for prostitution (prost. text)
lincom (sgroupsd11+ideol_11_3-sgroupsd10-ideol_10_3)

// est. diff in favor of prostitution between prost. text and no text
lincom (sgroupsd11+ideol_11_3-sgroupsd10-ideol_10_3)-(sgroupsd4+ideol_4_3-ideol_1_3)


//LIBERALS - CONSERVATIVES
//est. share for prostitution with no txt:
lincom ideol_4_2-ideol_1_2

//est. share for prostitution (prost. text)
lincom ideol_11_2-ideol_10_2

//diff between the two
lincom (ideol_11_2-ideol_10_2)-(ideol_4_2-ideol_1_2)


//LIBERALS - MODERATES
//est. share for prostitution with no txt:
lincom (ideol_4_2-ideol_1_2)-(ideol_4_3-ideol_1_3)

//est. share for prostitution (prost. text)
lincom (ideol_11_2-ideol_10_2)-(ideol_11_3-ideol_10_3)

//diff between the two
lincom ((ideol_11_2-ideol_10_2)-(ideol_11_3-ideol_10_3)) - ((ideol_4_2-ideol_1_2)-(ideol_4_3-ideol_1_3))


//MODERATES - CONSERVATIVES
//est. share for prostitution with no txt:
lincom ideol_4_3-ideol_1_3

//est. share for prostitution (prost. text)
lincom ideol_11_3-ideol_10_3

//diff between the two
lincom (ideol_11_3-ideol_10_3) - (ideol_4_3-ideol_1_3)



//INCOME

mean y, over(highearn sgroups)

*prostitution

reg y $conditions highearn_1-highearn_11 if prostitution==1

//<2500

//est. share for legalizing prostitution with no txt is coefficient on sgroupd3:

//est. share for legalizing prostitution (prostitution text)
lincom (sgroupsd9-sgroupsd7)

// est. diff in favor of legalizing prostitution between prostitution text and no text
lincom (sgroupsd9-sgroupsd7)-(sgroupsd3)


//>2500

//est. share for org.mkt with no txt
lincom (sgroupsd3+highearn_3)-highearn_1

//est. share for org.mkt (pros text)
lincom (sgroupsd9+highearn_9-sgroupsd7-highearn_7)

// est. diff in favor of legalizing prostitution between prostitution text and no text
lincom (sgroupsd9+highearn_9-sgroupsd7-highearn_7)-((sgroupsd3+highearn_3)-highearn_1)


//>2500 VS <2500
//est. share for legalizing prostitution with no txt:
lincom (highearn_3)-highearn_1

//est. share for legalizing prostitution (pros text)
lincom (highearn_9-highearn_7)

//difference between the two
lincom highearn_9-highearn_7-(highearn_3)+highearn_1


*slavery

reg y $conditions highearn_1-highearn_11 if slavery==1

//<2500

//est. share for legalizing slavery with no txt is coefficient on sgroupd4

//est. share for legalizing slavery (slavery text)
lincom (sgroupsd11-sgroupsd10)

// est. diff in favor of legalizing slavery between slavery text and no text
lincom (sgroupsd11-sgroupsd10)-(sgroupsd4)


//>2500

//est. share for slavery with no txt
lincom (sgroupsd4+highearn_4)-highearn_1

//est. share for slavery (slavery text)
lincom (sgroupsd11+highearn_11-sgroupsd10-highearn_10)

// est. diff in favor of legalizing slavery between slavery text and no text
lincom (sgroupsd11+highearn_11-sgroupsd10-highearn_10)-((sgroupsd4+highearn_4)-highearn_1)


//>2500 VS <2500
//est. share for slavery with no txt:
lincom (highearn_4)-highearn_1

//est. share for slavery (slavery text)
lincom (highearn_11-highearn_10)

//difference between the two
lincom  (highearn_11-highearn_10) - ((highearn_4)-highearn_1)



//WITH CONTROL VARIABLES

*prostitution

reg y $conditions highearn_1-highearn_11 $controls if prostitution==1

//<2500

//est. share for legalizing prostitution with no txt is coefficient on sgroupd3:

//est. share for legalizing prostitution (prostitution text)
lincom (sgroupsd9-sgroupsd7)

// est. diff in favor of legalizing prostitution between prostitution text and no text
lincom (sgroupsd9-sgroupsd7)-(sgroupsd3)


//>2500

//est. share for org.mkt with no txt
lincom (sgroupsd3+highearn_3)-highearn_1

//est. share for org.mkt (pros text)
lincom (sgroupsd9+highearn_9-sgroupsd7-highearn_7)

// est. diff in favor of legalizing prostitution between prostitution text and no text
lincom (sgroupsd9+highearn_9-sgroupsd7-highearn_7)-((sgroupsd3+highearn_3)-highearn_1)


//>2500 VS <2500
//est. share for legalizing prostitution with no txt:
lincom (highearn_3)-highearn_1

//est. share for legalizing prostitution (pros text)
lincom (highearn_9-highearn_7)

//difference between the two
lincom highearn_9-highearn_7-(highearn_3)+highearn_1


*slavery

reg y $conditions highearn_1-highearn_11 $controls if slavery==1

//<2500

//est. share for legalizing slavery with no txt is coefficient on sgroupd4

//est. share for legalizing slavery (slavery text)
lincom (sgroupsd11-sgroupsd10)

// est. diff in favor of legalizing slavery between slavery text and no text
lincom (sgroupsd11-sgroupsd10)-(sgroupsd4)


//>2500

//est. share for slavery with no txt
lincom (sgroupsd4+highearn_4)-highearn_1

//est. share for slavery (slavery text)
lincom (sgroupsd11+highearn_11-sgroupsd10-highearn_10)

// est. diff in favor of legalizing slavery between slavery text and no text
lincom (sgroupsd11+highearn_11-sgroupsd10-highearn_10)-((sgroupsd4+highearn_4)-highearn_1)


//>2500 VS <2500
//est. share for slavery with no txt:
lincom (highearn_4)-highearn_1

//est. share for slavery (slavery text)
lincom (highearn_11-highearn_10)

//difference between the two
lincom  (highearn_11-highearn_10) - ((highearn_4)-highearn_1)


